@@ -1,5 +1,5 @@
 //
-// "$Id: factory.cxx,v 1.4.2.6 2000/06/05 21:20:42 mike Exp $"
+// "$Id: factory.cxx,v 1.4.2.8 2000/11/21 21:37:08 easysw Exp $"
 //
 // Widget factory code for the Fast Light Tool Kit (FLTK).
 //
@@ -36,6 +36,7 @@
 #include <FL/Fl_Menu_Item.H>
 #include <string.h>
 #include <stdio.h>
+#include <config.h>
 
 #if defined(WIN32) || defined(__EMX__)
 #define strcasecmp stricmp
@@ -43,6 +44,34 @@
 
 #include "Fl_Widget_Type.h"
 
+#if !HAVE_STRCASECMP
+#  include <ctype.h>
+
+//
+// 'strcasecmp()' - Do a case-insensitive compare...
+//
+
+static int
+strcasecmp(const char *s, const char *t) {
+  while (*s != '\0' && *t != '\0') {
+    if (tolower(*s) < tolower(*t))
+      return (-1);
+    else if (tolower(*s) > tolower(*t))
+      return (1);
+
+    s ++;
+    t ++;
+  }
+
+  if (*s == '\0' && *t == '\0')
+    return (0);
+  else if (*s != '\0')
+    return (1);
+  else
+    return (-1);
+}
+#endif // !HAVE_STRCASECMP
+
 ////////////////////////////////////////////////////////////////
 
 #include <FL/Fl_Box.H>
@@ -693,5 +722,5 @@ int lookup_symbol(const char *name, int &v, int numberok) {
 }
 
 //
-// End of "$Id: factory.cxx,v 1.4.2.6 2000/06/05 21:20:42 mike Exp $".
+// End of "$Id: factory.cxx,v 1.4.2.8 2000/11/21 21:37:08 easysw Exp $".
 //
