@@ -1,5 +1,5 @@
 //
-// "$Id: Fl.cxx,v 1.24.2.30 2000/06/21 17:36:36 bill Exp $"
+// "$Id: Fl.cxx,v 1.24.2.34 2000/11/20 19:02:20 easysw Exp $"
 //
 // Main event handling code for the Fast Light Tool Kit (FLTK).
 //
@@ -30,6 +30,7 @@
 #include <stdlib.h>
 #include <string.h>
 
+
 //
 // Globals...
 //
@@ -47,7 +48,7 @@ int		Fl::damage_,
 		Fl::e_clicks,
 		Fl::e_is_click,
 		Fl::e_keysym;
-char		*Fl::e_text = "";
+char		*Fl::e_text = (char *)"";
 int		Fl::e_length;
 
 //
@@ -343,7 +344,6 @@ void Fl::belowmouse(Fl_Widget *o) {
   if (grab()) return; // don't do anything while grab is on
   Fl_Widget *p = belowmouse_;
   if (o != p) {
-    event_is_click(0);
     belowmouse_ = o;
     for (; p && !p->contains(o); p = p->parent()) p->handle(FL_LEAVE);
   }
@@ -372,6 +372,7 @@ void fl_fix_focus() {
   // set focus based on Fl::modal() and fl_xfocus
   Fl_Widget* w = fl_xfocus;
   if (w) {
+    Fl::e_keysym = 0; // make sure widgets don't think a keystroke moved focus
     while (w->parent()) w = w->parent();
     if (Fl::modal()) w = Fl::modal();
     if (!w->contains(Fl::focus()))
@@ -599,7 +600,11 @@ void Fl_Window::hide() {
   if (x->region) XDestroyRegion(x->region);
 #endif
   XDestroyWindow(fl_display, x->xid);
-
+#ifdef WIN32
+  // Try to stop the annoying "raise another program" behavior
+  if (non_modal() && Fl::first_window() && Fl::first_window()->shown())
+    Fl::first_window()->show();
+#endif
   delete x;
 }
 
@@ -729,5 +734,5 @@ void Fl_Window::flush() {
 }
 
 //
-// End of "$Id: Fl.cxx,v 1.24.2.30 2000/06/21 17:36:36 bill Exp $".
+// End of "$Id: Fl.cxx,v 1.24.2.34 2000/11/20 19:02:20 easysw Exp $".
 //
