@@ -1,5 +1,5 @@
 //
-// "$Id: Fl_x.cxx,v 1.24.2.18 2000/06/18 00:38:41 bill Exp $"
+// "$Id: Fl_x.cxx,v 1.24.2.22 2000/11/20 19:02:20 easysw Exp $"
 //
 // X specific code for the Fast Light Tool Kit (FLTK).
 //
@@ -242,17 +242,24 @@ static Atom wm_delete_window;
 static Atom wm_protocols;
 static Atom _motif_wm_hints;
 
-static void fd_callback(int,void *) {do_queued_events();}
+static void fd_callback(int,void *) {
+  do_queued_events();
+}
 
-static int io_error_handler(Display*) {Fl::fatal("X I/O error"); return 0;}
+extern "C" {
+  static int io_error_handler(Display*) {
+    Fl::fatal("X I/O error");
+    return 0;
+  }
 
-static int xerror_handler(Display* d, XErrorEvent* e) {
-  char buf1[128], buf2[128];
-  sprintf(buf1, "XRequest.%d", e->request_code);
-  XGetErrorDatabaseText(d,"",buf1,buf1,buf2,128);
-  XGetErrorText(d, e->error_code, buf1, 128);
-  Fl::warning("%s: %s 0x%lx", buf2, buf1, e->resourceid);
-  return 0;
+  static int xerror_handler(Display* d, XErrorEvent* e) {
+    char buf1[128], buf2[128];
+    sprintf(buf1, "XRequest.%d", e->request_code);
+    XGetErrorDatabaseText(d,"",buf1,buf1,buf2,128);
+    XGetErrorText(d, e->error_code, buf1, 128);
+    Fl::warning("%s: %s 0x%lx", buf2, buf1, e->resourceid);
+    return 0;
+  }
 }
 
 void fl_open_display() {
@@ -338,8 +345,8 @@ static void set_event_xy() {
   if (fl_key_vector[18]&0x18) Fl::e_state |= FL_META;
 #endif
   // turn off is_click if enough time or mouse movement has passed:
-  if (abs(Fl::e_x_root-px)+abs(Fl::e_y_root-py) > 3 
-      || fl_event_time >= ptime+1000)
+  if (abs(Fl::e_x_root-px)+abs(Fl::e_y_root-py) > 3 ||
+      fl_event_time >= ptime+1000)
     Fl::e_is_click = 0;
 }
 
@@ -362,7 +369,6 @@ static Fl_Window* resize_bug_fix;
 
 int fl_handle(const XEvent& xevent)
 {
-  Fl::e_keysym = 0;
   fl_xevent = &xevent;
   Window xid = xevent.xany.window;
 
@@ -519,7 +525,8 @@ int fl_handle(const XEvent& xevent)
     Fl::e_keysym = int(keysym);
     Fl::e_text = buffer;
     Fl::e_length = len;
-    set_event_xy(); Fl::e_is_click = 0;
+    set_event_xy();
+    Fl::e_is_click = 0;
     if (Fl::event_state(FL_CTRL) && keysym == '-') buffer[0] = 0x1f; // ^_
     event = FL_KEYBOARD;
     break;}
@@ -896,5 +903,5 @@ void Fl_Window::make_current() {
 #endif
 
 //
-// End of "$Id: Fl_x.cxx,v 1.24.2.18 2000/06/18 00:38:41 bill Exp $".
+// End of "$Id: Fl_x.cxx,v 1.24.2.22 2000/11/20 19:02:20 easysw Exp $".
 //
