@@ -1,9 +1,9 @@
 //
-// "$Id: filename_ext.cxx,v 1.4 1999/01/07 19:17:34 mike Exp $"
+// "$Id: filename_ext.cxx,v 1.4.2.3 2000/06/05 21:21:04 mike Exp $"
 //
 // Filename extension routines for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-1999 by Bill Spitzak and others.
+// Copyright 1998-2000 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@easysw.com".
+// Please report all bugs and problems to "fltk-bugs@fltk.org".
 //
 
 // returns pointer to the last '.' or to the null if none:
@@ -32,7 +32,7 @@ const char *filename_ext(const char *buf) {
   const char *p = buf;
   for (p=buf; *p; p++) {
     if (*p == '/') q = 0;
-#if defined(WIN32) || defined(__EMX__)
+#if defined(WIN32) || defined(__EMX__) && !defined(__CYGWIN__)
     else if (*p == '\\') q = 0;
 #endif
     else if (*p == '.') q = p;
@@ -41,5 +41,5 @@ const char *filename_ext(const char *buf) {
 }
 
 //
-// End of "$Id: filename_ext.cxx,v 1.4 1999/01/07 19:17:34 mike Exp $".
+// End of "$Id: filename_ext.cxx,v 1.4.2.3 2000/06/05 21:21:04 mike Exp $".
 //
