@@ -1,5 +1,5 @@
 //
-// "$Id: CubeMain.cxx,v 1.2.2.2 2000/06/05 21:21:14 mike Exp $"
+// "$Id: CubeMain.cxx,v 1.2.2.3 2000/08/20 04:35:17 spitzak Exp $"
 //
 // CubeView class definitions for the Fast Light Tool Kit (FLTK).
 //
@@ -28,7 +28,7 @@
 #include "CubeViewUI.h"
 
 int
-main(int argc, char **argv) {
+main(int /*argc*/, char **/*argv*/) {
 
     CubeViewUI *cvui=new CubeViewUI;
     
@@ -43,5 +43,5 @@ main(int argc, char **argv) {
 
 
 //
-// End of "$Id: CubeMain.cxx,v 1.2.2.2 2000/06/05 21:21:14 mike Exp $".
+// End of "$Id: CubeMain.cxx,v 1.2.2.3 2000/08/20 04:35:17 spitzak Exp $".
 //
